@@ -247,6 +247,26 @@ gboolean	e_cal_util_event_dates_match	(icalcomponent *icalcomp1,
  **/
 #define CAL_STATIC_CAPABILITY_TASK_NO_ALARM		"task-no-alarm"
 
+/**
+ * CAL_STATIC_CAPABILITY_COMPONENT_COLOR:
+ *
+ * When the capability is set, the client supports storing color
+ * for individual components.
+ *
+ * Since: 3.30
+ **/
+#define CAL_STATIC_CAPABILITY_COMPONENT_COLOR		"component-color"
+
+/**
+ * CAL_STATIC_CAPABILITY_TASK_HANDLE_RECUR:
+ *
+ * When the capability is set, the backend handles task recurrence
+ * completion on its own. This does not imply CAL_STATIC_CAPABILITY_TASK_CAN_RECUR.
+ *
+ * Since: 3.34
+ **/
+#define CAL_STATIC_CAPABILITY_TASK_HANDLE_RECUR		"task-handle-recur"
+
 /* Recurrent events. Management for instances */
 icalcomponent *	e_cal_util_construct_instance	(icalcomponent *icalcomp,
 						 struct icaltimetype rid);
