@@ -143,7 +143,9 @@ typedef enum {
 	E_WEBDAV_LIST_CREATION_DATE	= 1 << 5,
 	E_WEBDAV_LIST_LAST_MODIFIED	= 1 << 6,
 	E_WEBDAV_LIST_DESCRIPTION	= 1 << 7,
-	E_WEBDAV_LIST_COLOR		= 1 << 8
+	E_WEBDAV_LIST_COLOR		= 1 << 8,
+	E_WEBDAV_LIST_ONLY_CALENDAR	= 1 << 9,
+	E_WEBDAV_LIST_ONLY_ADDRESSBOOK	= 1 << 10
 } EWebDAVListFlags;
 
 /**
@@ -364,6 +366,16 @@ gboolean	e_webdav_session_post_sync		(EWebDAVSession *webdav,
 							 GByteArray **out_content,
 							 GCancellable *cancellable,
 							 GError **error);
+gboolean	e_webdav_session_post_with_content_type_sync
+							(EWebDAVSession *webdav,
+							 const gchar *uri,
+							 const gchar *data,
+							 gsize data_length,
+							 const gchar *in_content_type,
+							 gchar **out_content_type,
+							 GByteArray **out_content,
+							 GCancellable *cancellable,
+							 GError **error);
 gboolean	e_webdav_session_propfind_sync		(EWebDAVSession *webdav,
 							 const gchar *uri,
 							 const gchar *depth,
